#ifndef DatTEMPLATE_HH
#define DatTEMPLATE_HH

#include "DatEnv.hh"
#include "MonServer.hh"
#include "FixedLenTS.hh"
#include "Trend.hh"
#include "autopipe.hh"
#include <string>

//
//    Data Monitor template class.

/**  @name DatTemplate
  *  @memo Template of a data environment (DatEnv) based monitor.
  *  The DatTemplate monitor is a template for a data monitor program.
  *  DatTemplate makes a simple calculation of the standard deviation of
  *  a specified channel (by default H0:PEM-LVEA_SEISX), serves the result 
  *  for display by the DMT viewer and stores the result as a minute trend.
  *
  *  {\bf {\Large Running DatTemplate}}
  *
  *  The DatTemplate command line syntax is:
  *  \begin{verbatim}
        DatTemplate [-channel <channel>] [-frames <number>] [-stride <time>] \
                    [-filter <filter>] [-settle <s-time>] [-dvIndex]
     \end{verbatim}
  *  The #<number># argument specifies the number of data strides to process
  *  before terminating the program. The #<time># argument specifies the data
  *  stride. If "-dvIndex" is specified, a trend index file will be written
  *  to '\$DMTOUTPUT/channel.cnf'.
  *
  *  {\bf {\Large Configuration File}}
  *
  *  DatTemplate uses a fixed configuration. There is therfore no 
  *  configuration file
  *
  *  {\bf {\Large DatTemplate Output}}
  *
  *  {\bf Trend channels}
  *  DatTemplate produces a minute trend of the sigma value called 
  *  #<channel>_sigma#
  *
  *  {\bf Monitor data channels}
  *  DatTemplate publishes a time series history of the sigma values 
  *  with the name #<channel>_sigma#
  *
  *  @author John Zweizig; Caltech/LIGO
  *  @version 1.1; Last modified August 12, 2004
  */
//{
//}

class DatTemplate : public DatEnv, MonServer {
public:
    DatTemplate(int argc, const char *argv[]);  // Constructor
    ~DatTemplate(void);                         // Destructor
    void ProcessData(void);                     // Process 1 data stride
    void Attention(void);                       // Handle Message signal.
private:
    int         maxFrame;       //  Number of frames to process
    Interval    mStep;          //  Time stride.
    Trend       mTrend;         //  Trend writer
    std::string mChannel;       //  Channel name
    std::string mFilter;        //  Filter description
    Interval    mSettle;        //  Settling time.
    std::string mSigmaName;     //  Channel data and trend name
    auto_pipe   mPipe;          // Pipe pointer
    FixedLenTS  mHistory;       //  X sigma history.
};

#endif     //  DatTEMPLATE_HH
